import { select } from 'd3';

export const updateTable = (data, gene) => {
  let filtered_data = data.filter(function (d) {
        return gene.indexOf(d.Gene_name) > -1
    })
  let keys = ["Gene_name","DEG","level1_len","level2_len","level1_list","level2_list"]
  
  let trs = d3.selectAll('tr').data(filtered_data.map(d => d.Gene_name));
  trs.attr('fill', 'black')
  trs.exit()
    .transition().delay(200)
    .duration(2000).style('opacity', '0')
    .remove();
};

export const geneInfoTable = (selection, props) => {
  const {
    full_data,
    inputGeneList,
    selectedGeneData
  } = props;
  
  d3.select("body").append("div")
    .attr("id", "FilterableTable")

  function init_table_data(data, full_data) {
      for(var i =0; i<full_data.length; i++){
        for (var j =0; j<data.length; j++){
            if (full_data[i]['gene'] == data[j]['Gene']){
                data[j]["level1_len"] = parseInt(full_data[i]["level1"].length)
                data[j]["level2_len"] = parseInt(full_data[i]["level2"].length)
                data[j]["Gene_name"] = full_data[i]["gene"]
                let temp_str1 = ''
                for(var v=0; v<full_data[i]["level1"].length; v++){
                    if(v == parseInt(full_data[i]["level1"].length) -1){
                        temp_str1 += full_data[i]["level1"][v]
                    }
                    else{
                        temp_str1 += full_data[i]["level1"][v]+', '
                    }
                }
                data[i]['level1_list'] = temp_str1;
                let temp_str2 = ''
                for(var v=0; v<full_data[i]["level2"].length; v++){
                    temp_str2 += full_data[i]["level2"][v]
                }
                data[i]['level2_list'] = temp_str2
            }
        }
      }
      return data
  }
        function init_table_input(data) {
          //********* - START TABLE - *********
            var sortAscending = true;
            var table = d3.select('#FilterableTable').append('table');
                table.append("thead").append("tr");
            var titles = ["Gene_name","DEG","level1_len","level2_len","level1_list","level2_list"]
            /** sort functionality **/
            var headers = table.append('thead').append('tr')
                .selectAll('th')
                .data(titles).enter()
                .append('th')
                .text(function(d) {
                    return d
                })
                .on('click', function(d) {
                    headers.attr('class', 'header');
                    if (d == "Gene_name" || d == "DEG" || d == "level1_list"|| d == "level2_list") { //these keys sort alphabetically
                    // sorting alphabetically");
                    if (sortAscending) {
                        rows.sort(function(a, b) {
                        return d3.ascending(a[d], b[d]);
                        });
                        sortAscending = false;
                        this.className = 'aes';
                    } else {
                        rows.sort(function(a, b) {
                        return d3.descending(a[d], b[d]);
                        });
                        sortAscending = true;
                        this.className = 'des';
                    }

                    } else {
                      if (sortAscending) {
                        //all other keys sort numerically including time
                        rows.sort(function(a, b) {
                          return b[d] - a[d];
                        });
                        sortAscending = false;
                        this.className = 'aes';
                      } else {
                        rows.sort(function(a, b) {
                          return a[d] - b[d];
                        });
                        sortAscending = true;
                        this.className = 'des';
                      }
                    }
              });

            var rows = table.append('tbody')
                            .selectAll('tr')
                            .data(data)
                            .enter()
                            .append('tr')
            							  .on("mouseover", function(d){ mon(d.Gene) })
														.on("mouseout", function(d){ mout(d.Gene) });

            rows.selectAll('td')
                .data(function(d) {
                    return titles.map(function(key, i) {return {
                        'value': d[key],
                        'name': d
                        };
                    });
                })
                .enter()
                .append('td')
                .attr('data-th', function(d) {
                    return d.name;
                })
                .text(function(d) {return d.value});
      }

    function mon(d) {

			d3.select('tbody').selectAll('tr').each(function (a) {
				if (d == a.Gene){
					d3.select(this).style('background-color', 'lightgrey').style('font-weight', 'bolder')
				}
			})		
  }
		function mout(d) {
			d3.select('tbody').selectAll('tr').each(function (a) {
				if (d == a.Gene){
					d3.select(this).style('background-color', 'white').style('font-weight', 'normal')
				}	
		})
	}
  
  
  let init_data = init_table_data(inputGeneList, full_data);
  init_table_input(init_data);
  
//  if (selectedGeneData.length != 0) {
//    updateTable(init_data, selectedGeneData.map(d => d.gene));
//  };

};