import { select, zoom, event } from 'd3';
import { loadAndProcessData } from './loadAndProcessData';
import { cellColorArea } from './cellColorArea';
import { cellShape } from './cellShape';
import { geneInfoTable, updateTable } from './geneInfoTable'
import { updateInfoTable } from './updateInfoTable'

// Define Variables
const cellSvg = select('#cellDrawingSvg');
const height = +cellSvg.attr('height');
const width = +cellSvg.attr('width');
const margin = { top: 60, right: 60, bottom: 60, left: 60 };
const cellDiagram = cellSvg.append('g');
const YCTable = cellSvg.append('g');
const treeMapDiagram = select('#treemap');
let full_data;
let locationData;
let inputGeneList;
let reducedData;
let rfdata;
let lvdata;
let refgene;
let Userdata;
let usrgene;

// Data Processing : load and process data & set a state & invoke rendering
loadAndProcessData().then(data => {
  full_data = data[0];
  locationData = data[1];
  inputGeneList = data[2];
  reducedData = data[3];
  rfdata = data[4];
  lvdata = data[5];
  refgene = data[6];
  Userdata = data[7];
  usrgene = data[8];
  render();
});

// Event Handler
let selectedLocation = null;
const onClick = id => {
  selectedLocation = id;
  update();
  updateRender();
  let lvv1= id;
  let intersection = usrgene.filter(v => refgene.includes(v))
  let arr2 = FillLv1ArrayValue(arr, intersection, rfdata, Userdata)
  ColorDataTransfer(arr2)
  let root = ArrToRoot(arr2)
  Vanish_all()
  let lv2= GetLv2List(lvv1)
  let arr1 = CreateOriArr(lv2)
  arr1 = FillLv2ArrayValue(arr1, intersection, rfdata, Userdata, lvv1)
  let root1 = ArrToRoot(arr1);
  DrawLv2TreeMap(root1, treemapG)
};

const update = () => {
    let selectedGeneData = reducedData.filter(d => d.level1.includes(selectedLocation));
  YCTable.call(updateInfoTable, {
     selectedGeneData,
    inputGeneList
  })
}

// render color area & cell diagram
const render = () => {
  // Filter by selected Location
  let selectedGeneData = reducedData.filter(d => d.level1.includes(selectedLocation));
  cellDiagram.call(cellShape, {
    height: height,
    width: width,
    margin: margin
  });
  
	cellDiagram.call(cellColorArea, {
    height: height,
    width: width,
    margin: margin,
    locationData,
    onClick,
    selectedLocation
  });

  YCTable.call(geneInfoTable, {
    full_data,
    inputGeneList,
    selectedGeneData
  });
};

// updateRender
const updateRender = () => {
  // Filter by selected Location
  let selectedGeneData = reducedData.filter(d => d.level1.includes(selectedLocation));
  cellDiagram.call(cellShape, {
    height: height,
    width: width,
    margin: margin
  });
  
	cellDiagram.call(cellColorArea, {
    height: height,
    width: width,
    margin: margin,
    locationData,
    onClick,
    selectedLocation
  });
};